Read results generated using the assocTest method.

readResults(path, type = NULL, sep = "\t")

Arguments

path

File path to data

type

Result type ('singlevarResult', 'rvbResult', 'gsaResult'). Defaults to NULL in which case the result type is inferred from the header.

sep

The field separator. Defaults to \\t, which is the default separator using in assocTest.

Value

An object of type rvbResult or singlevarResult.