vcfInfo2Table.RdConvert vcf info field to table format. Requires valid vcf where INFO fields are specified in the header.
vcfInfo2Table(vcf, output, splitMultiallelic = TRUE)Input vcf file path.
Output file path
Returns one row per alternative allele instead of one row per variant.
Note that this option currently simply duplicates the information in the INFO field for each allele;
it does not parse Number='A' or Number='R' INFO fields to extract allele-specific values.
Defaults to TRUE.
library(rvatData)
vcf <- rvat_example("rvatData.vcf.gz")
output <- tempfile()
vcfInfo2Table(
vcf = vcf,
output = output
)
#> Detected INFO field AC
#> Detected INFO field AN
#> Detected INFO field AF
#> Detected INFO field gene_name
#> Detected INFO field HighImpact
#> Detected INFO field ModerateImpact
#> Detected INFO field Synonymous
#> Detected INFO field CADDphred
#> Detected INFO field PolyPhen
#> Detected INFO field SIFT