readResults.RdRead results generated using the assocTest method.
readResults(path, type = NULL, sep = "\t")File path to data
Result type ('singlevarResult', 'rvbResult', 'gsaResult').
Defaults to NULL in which case the result type is inferred from the header.
The field separator. Defaults to \\t, which is the default separator using in assocTest.
An object of type rvbResult or singlevarResult.